%global major_ver 21
%global gm_state_dir %{_sharedstatedir}/gnumed
%global gm_server_dir %{gm_state_dir}/server

Name:		gnumed-server
Version:	%{major_ver}.7
Release:	7%{?dist}
Summary:	The GNUmed back end server
%if 0%{?rhel}
Group:		Applications/Productivity
%endif
License:	GPLv2+
URL:		http://wiki.gnumed.de/
Source0:	http://www.gnumed.de/downloads/server/v%{major_ver}/%{name}.%{version}.tgz
BuildArch:  noarch

Requires: python2
Requires: python2-psycopg2
# bootstrap requires files from client package
Requires: gnumed
Requires: mailx
Requires: bzip2
Requires: gnupg2
Requires: openssl
Requires: postgresql-server
Requires: rsync
Requires: python2-egenix-mx-base

%description
The GNUmed project builds an open source Electronic Medical Record.
It is developed by a handful of medical doctors and programmers from
all over the world. It can be useful to anyone documenting the health
of patients, including but not limited to doctors, physical therapists,
occupational therapists.

%prep
%setup -q -n gnumed-server.%{version}

%build

%install
pushd server

#Copy to %%{gm_server_dir}
mkdir -p %{buildroot}%{gm_server_dir}
ln -s %{gm_server_dir} %{buildroot}%{gm_state_dir}/Gnumed
for dirent in bootstrap pycommon sql __init__.py;
do
  cp -pr $dirent %{buildroot}%{gm_server_dir}/
done
echo "%{version}" > %{buildroot}%{gm_server_dir}/version.txt

# silence bootstrap process by setting interactive to 'no' and set 'gm-dbo' as default password
for conffile in `find %{buildroot}/%{gm_server_dir}/bootstrap -maxdepth 1 -type f -name \*.conf` ; do \
   sed -i -e 's/^\(interactive[[:space:]]*=[[:space:]]*\)yes/\1no/' \
          -e 's/^\(password[[:space:]]*=[[:space:]]*\)/\1 gm-dbo/' "$conffile" ; \
done


#copy config files to /etc
mkdir -p %{buildroot}%{_sysconfdir}/gnumed
for conf in `ls etc/gnumed/*.conf.example`;
    do mv $conf `echo $conf|sed 's/.example//'`;
done
cp -p -r etc/gnumed/*.conf %{buildroot}%{_sysconfdir}/gnumed

#create .gz files and copy them to mandir
mkdir -p %{buildroot}%{_mandir}/man8/
mkdir -p %{buildroot}%{_mandir}/man1/

for man in `ls doc/*.*`; \
    do gzip $man; \
done
cp -p doc/*.8.gz %{buildroot}%{_mandir}/man8
cp -p doc/*.1.gz %{buildroot}%{_mandir}/man1


#remove .sh extensions
#copy all scripts to bin dir
mkdir -p %{buildroot}%{_bindir}
rename ".sh" "" *.sh
cp gm-* %{buildroot}%{_bindir}


popd


%files
%doc server/GnuPublicLicense.txt server/doc/README server/doc/schema
%{gm_state_dir}
%{_bindir}/gm-*
%{_mandir}/man8/gm-*
%{_mandir}/man1/gm-*
%config(noreplace) %{_sysconfdir}/gnumed/*.conf

%changelog
* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 21.7-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 21.7-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Jan 05 2018 Iryna Shcherbina <ishcherb@redhat.com> - 21.7-5
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 21.7-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 21.7-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Jul 19 2016 Ville Skyttä <ville.skytta@iki.fi> - 21.7-2
- Don't ship sed backup files (#1087458)

* Thu Jul  7 2016 Michel Alexandre Salim <salimma@fedoraproject.org> - 21.7-1
- Update to v21.7

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 19.8-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 19.8-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 19.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu May 22 2014 Michel Salim <salimma@fedoraproject.org> - 19.8-1
- Update to v19.8

* Wed Jan 29 2014 Michel Salim <salimma@fedoraproject.org> - 19.5-1
- Update to v19.5

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 18.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Jul  5 2013 Michel Salim <salimma@fedoraproject.org> - 18.6-1
- Update to v18.6

* Fri Jun 14 2013 Michel Salim <salimma@fedoraproject.org> - 18.5-1
- Update to v18.5

* Sat May 18 2013 Michel Salim <salimma@fedoraproject.org> - 18.4-1
- Update to v18.4

* Sat Apr 20 2013 Michel Salim <salimma@fedoraproject.org> - 18.3-1
- Update to v18.3

* Mon Apr  8 2013 Michel Salim <salimma@fedoraproject.org> - 18.2-1
- Update to v18.2

* Sat Mar 23 2013 Michel Salim <salimma@fedoraproject.org> - 18.1-1
- Update to v18.1

* Mon Mar 18 2013 Michel Salim <salimma@fedoraproject.org> - 18.0-1
- Update to v18.0

* Sat Mar 16 2013 Michel Salim <salimma@fedoraproject.org> - 17.9-1
- Update to v17.9

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 17.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Nov 21 2012 Michel Salim <salimma@fedoraproject.org> - 17.6-2
- Require postgresql-server, not postgresql

* Tue Nov 20 2012 Michel Salim <salimma@fedoraproject.org> - 17.6-1
- Update to v17.6

* Sat Aug  4 2012 Michel Salim <salimma@fedoraproject.org> - 16.18-1
- Update to v16.18

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 16.14-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jun  1 2012 Michel Salim <salimma@fedoraproject.org> - 16.14-1
- Update to v16.14
- Revert to installing to default directories; gnumed-server depends on
  gnumed client anyway, and installs symlinks assuming the default
  directory depth
- Update license field

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 15.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild


* Tue Jun 07 2011 - Susmit Shannigrahi <susmit@fedoraproject.org> - 15.5-2
- Fixing backup-file-in-package.

* Tue Jun 07 2011 - Susmit Shannigrahi <susmit@fedoraproject.org> - 15.5-1
- New upstream release
- PostgreSQL provides PostgreSQL-client and PostgreSQL-filedump.
- No need to include them explicitly.

* Sun May 29 2011 - Susmit Shannigrahi <susmit@fedoraproject.org> - 14.8-1
- New upstream release.
- Correcting spec based on review.

* Sun Feb 27 2011 - Susmit Shannigrahi <susmit@fedoraproject.org> - 14.7-1
- New upstream release
- Added mx as dependency
- Fixing file permission for bindir, mandir

* Sun Feb 27 2011 - Susmit Shannigrahi <susmit@fedoraproject.org> - 14.6-2
- Whole lot of fixes the spec file.

* Wed Jan 12 2011 - Susmit Shannigrahi <susmit@fedoraproject.org> - 14.6-1
- New upstream release.

* Sun Jan 02 2011 - Susmit Shannigrahi <susmit@fedoraproject.org> - 14.5-1
- Initial packaging based on Sebastian Hilbert's unofficial package for F13.
